==> tekton-model-triggers-v1alpha1-6.6.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;

 /**
  * Generated
  */
public interface EventListenerSpecFluent<A extends EventListenerSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> withNewLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public EventListenerSpecFluent.LabelSelectorNested<A> editLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public NamespaceSelector getNamespaceSelector();
  public NamespaceSelector buildNamespaceSelector();
  public A withNamespaceSelector(NamespaceSelector namespaceSelector);
  public Boolean hasNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(NamespaceSelector item);
  public EventListenerSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(NamespaceSelector item);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public Resources getResources();
  public Resources buildResources();
  public A withResources(Resources resources);
  public Boolean hasResources();
  public EventListenerSpecFluent.ResourcesNested<A> withNewResources();
  public EventListenerSpecFluent.ResourcesNested<A> withNewResourcesLike(Resources item);
  public EventListenerSpecFluent.ResourcesNested<A> editResources();
  public EventListenerSpecFluent.ResourcesNested<A> editOrNewResources();
  public EventListenerSpecFluent.ResourcesNested<A> editOrNewResourcesLike(Resources item);
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  public A addToTriggers(Integer index,EventListenerTrigger item);
  public A setToTriggers(Integer index,EventListenerTrigger item);
  public A addToTriggers(io.fabric8.tekton.triggers.v1alpha1.EventListenerTrigger... items);
  public A addAllToTriggers(Collection<EventListenerTrigger> items);
  public A removeFromTriggers(io.fabric8.tekton.triggers.v1alpha1.EventListenerTrigger... items);
  public A removeAllFromTriggers(Collection<EventListenerTrigger> items);
  public A removeMatchingFromTriggers(Predicate<EventListenerTriggerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTriggers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<EventListenerTrigger> getTriggers();
  public List<EventListenerTrigger> buildTriggers();
  public EventListenerTrigger buildTrigger(Integer index);
  public EventListenerTrigger buildFirstTrigger();
  public EventListenerTrigger buildLastTrigger();
  public EventListenerTrigger buildMatchingTrigger(Predicate<EventListenerTriggerBuilder> predicate);
  public Boolean hasMatchingTrigger(Predicate<EventListenerTriggerBuilder> predicate);
  public A withTriggers(List<EventListenerTrigger> triggers);
  public A withTriggers(io.fabric8.tekton.triggers.v1alpha1.EventListenerTrigger... triggers);
  public Boolean hasTriggers();
  public EventListenerSpecFluent.TriggersNested<A> addNewTrigger();
  public EventListenerSpecFluent.TriggersNested<A> addNewTriggerLike(EventListenerTrigger item);
  public EventListenerSpecFluent.TriggersNested<A> setNewTriggerLike(Integer index,EventListenerTrigger item);
  public EventListenerSpecFluent.TriggersNested<A> editTrigger(Integer index);
  public EventListenerSpecFluent.TriggersNested<A> editFirstTrigger();
  public EventListenerSpecFluent.TriggersNested<A> editLastTrigger();
  public EventListenerSpecFluent.TriggersNested<A> editMatchingTrigger(Predicate<EventListenerTriggerBuilder> predicate);
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<EventListenerSpecFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  public interface NamespaceSelectorNested<N> extends Nested<N>,NamespaceSelectorFluent<EventListenerSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  public interface ResourcesNested<N> extends Nested<N>,ResourcesFluent<EventListenerSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  public interface TriggersNested<N> extends Nested<N>,EventListenerTriggerFluent<EventListenerSpecFluent.TriggersNested<N>>{
    public N and();
    public N endTrigger();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;

 /**
  * Generated
  */
public interface EventListenerSpecFluent<A extends EventListenerSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> withNewLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public EventListenerSpecFluent.LabelSelectorNested<A> editLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public EventListenerSpecFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public NamespaceSelector getNamespaceSelector();
  public NamespaceSelector buildNamespaceSelector();
  public A withNamespaceSelector(NamespaceSelector namespaceSelector);
  public Boolean hasNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(NamespaceSelector item);
  public EventListenerSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public EventListenerSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(NamespaceSelector item);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public Resources getResources();
  public Resources buildResources();
  public A withResources(Resources resources);
  public Boolean hasResources();
  public EventListenerSpecFluent.ResourcesNested<A> withNewResources();
  public EventListenerSpecFluent.ResourcesNested<A> withNewResourcesLike(Resources item);
  public EventListenerSpecFluent.ResourcesNested<A> editResources();
  public EventListenerSpecFluent.ResourcesNested<A> editOrNewResources();
  public EventListenerSpecFluent.ResourcesNested<A> editOrNewResourcesLike(Resources item);
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  public A addToTriggers(int index,EventListenerTrigger item);
  public A setToTriggers(int index,EventListenerTrigger item);
  public A addToTriggers(io.fabric8.tekton.triggers.v1alpha1.EventListenerTrigger... items);
  public A addAllToTriggers(Collection<EventListenerTrigger> items);
  public A removeFromTriggers(io.fabric8.tekton.triggers.v1alpha1.EventListenerTrigger... items);
  public A removeAllFromTriggers(Collection<EventListenerTrigger> items);
  public A removeMatchingFromTriggers(Predicate<EventListenerTriggerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTriggers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<EventListenerTrigger> getTriggers();
  public List<EventListenerTrigger> buildTriggers();
  public EventListenerTrigger buildTrigger(int index);
  public EventListenerTrigger buildFirstTrigger();
  public EventListenerTrigger buildLastTrigger();
  public EventListenerTrigger buildMatchingTrigger(Predicate<EventListenerTriggerBuilder> predicate);
  public Boolean hasMatchingTrigger(Predicate<EventListenerTriggerBuilder> predicate);
  public A withTriggers(List<EventListenerTrigger> triggers);
  public A withTriggers(io.fabric8.tekton.triggers.v1alpha1.EventListenerTrigger... triggers);
  public Boolean hasTriggers();
  public EventListenerSpecFluent.TriggersNested<A> addNewTrigger();
  public EventListenerSpecFluent.TriggersNested<A> addNewTriggerLike(EventListenerTrigger item);
  public EventListenerSpecFluent.TriggersNested<A> setNewTriggerLike(int index,EventListenerTrigger item);
  public EventListenerSpecFluent.TriggersNested<A> editTrigger(int index);
  public EventListenerSpecFluent.TriggersNested<A> editFirstTrigger();
  public EventListenerSpecFluent.TriggersNested<A> editLastTrigger();
  public EventListenerSpecFluent.TriggersNested<A> editMatchingTrigger(Predicate<EventListenerTriggerBuilder> predicate);
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<EventListenerSpecFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  public interface NamespaceSelectorNested<N> extends Nested<N>,NamespaceSelectorFluent<EventListenerSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  public interface ResourcesNested<N> extends Nested<N>,ResourcesFluent<EventListenerSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  public interface TriggersNested<N> extends Nested<N>,EventListenerTriggerFluent<EventListenerSpecFluent.TriggersNested<N>>{
    public N and();
    public N endTrigger();
    
  }
  
}
